@@ -3,8 +3,8 @@
 """Top-level package for moco-wrapper."""
 
 __author__ = """Sommalia"""
-__email__ = 'sommalia@tuta.io'
-__version__ = '0.9.0'
+__email__ = 'sommalia@protonmail.com'
+__version__ = '0.10.0'
 
 from . import models
 from . import util
