@@ -3,10 +3,15 @@
 """Top-level package for moco-wrapper."""
 
 __author__ = """Sommalia"""
-__email__ = 'sommalia@tuta.io'
-__version__ = '0.1.0'
+__email__ = 'sommalia@protonmail.com'
+__version__ = '0.10.0'
 
 from .activity import Activity
+
+from .account_fixed_cost import AccountFixedCost
+from .account_hourly_rate import AccountHourlyRate
+from .account_internal_hourly_rate import AccountInternalHourlyRate
+
 from .contact import Contact
 from .company import Company
 from .comment import Comment
@@ -38,7 +43,7 @@ from .project_payment_schedule import ProjectPaymentSchedule
 from .purchase_category import PurchaseCategory
 from .purchase import Purchase
 
-from .hourly_rate import HourlyRate
+
 
 from .session import Session
 
