@@ -3,10 +3,11 @@
 """Top-level package for moco-wrapper.util"""
 
 __author__ = """Sommalia"""
-__email__ = 'sommalia@tuta.io'
-__version__ = '0.1.0'
+__email__ = 'sommalia@protonmail.com'
+__version__ = '0.10.0'
 
 from . import generator
 from . import requestor
 from . import objector
 from . import response
+from . import endpoint
