@@ -84,7 +84,7 @@ class DefaultObjector(BaseObjector):
                 "base": "Schedule"
             },
             "session": {
-                "base": "Session"
+                "base": "SessionAuthentication"
             },
             "purchases": {
                 "base": "Purchase",
@@ -93,6 +93,10 @@ class DefaultObjector(BaseObjector):
             "planning_entries": {
                 "base": "PlanningEntry"
             },
+            "account": {
+                "hourly_rates": "HourlyRate",
+                "fixed_costs": "AccountFixedCost",
+            },
             "hourly_rates": {
                 "base": "HourlyRate"
             },
@@ -190,6 +194,31 @@ class DefaultObjector(BaseObjector):
 
         return requestor_response
 
+    def convert_e(self, requestor_response, endpoint):
+        http_response = requestor_response.response
+
+        if isinstance(requestor_response, ObjectResponse) and endpoint.type is not None:
+            obj = endpoint.type(**requestor_response.data)
+            requestor_response._data = obj
+        elif isinstance(requestor_response, (ListResponse, PagedListResponse)) and endpoint.type is not None:
+            obj_list = [endpoint.type(**x) for x in requestor_response.items]
+            requestor_response._data = obj_list
+        elif isinstance(requestor_response, ErrorResponse):
+            # convert the data for the error response into an actual exception
+            class_name = self.get_error_class_name_from_response_status_code(http_response.status_code)
+
+            if class_name is not None:
+                class_ = getattr(
+                    import_module(self.error_module_path),
+                    class_name
+                )
+
+                # overwrite data of the error response with the actual exception
+                obj = class_(http_response, requestor_response.data)
+                requestor_response._data = obj
+
+        return requestor_response
+
     def get_error_class_name_from_response_status_code(self, status_code) -> str:
         """
         Get the class name of the exception class based on the given http status code
